# import required module
from .tfidf_transformation_berk import TfidfTransformer

# assign documents
doc0 = 'A Scandal in Bohemia'
doc1 = 'The Red-headed League'
doc2 = 'A Case of Identity'
doc3 = 'The Boscombe Valley Mystery'
doc4 = 'The Five Orange Pips'
doc5 = 'The Man with the Twisted Lip'
doc6 = 'The Adventure of the Blue Carbuncle'
doc7 = 'The Adventure of the Speckled Band'
doc8 = "The Adventure of the Noble Bachelor"

# merge documents
documents = [doc0,doc1,doc2,doc3,doc4,doc5,doc6,doc7,doc8]

# create object
tfidf = TfidfTransformer()

# fit documents 
tfidf.fit(documents)

# transform documents 
transform = tfidf.transform(documents)
# display tf-idf scores 
print(transform)

# get tf-idf values
# this steps generates word counts for the words in documents
fit_transform = tfidf.fit_transform(documents)
# display tf-idf values
print(fit_transform)

# We have 9 rows (9 docs) and 27 columns (27 unique words, minus single character words)
fit_transform.shape

# get feature names
feature_names = tfidf.get_feature_names()[0:5]
# display feature names
print(feature_names)


import unittest
from tfidf_transformation_brk import TfidfTransformer

class TestTfidfTransformer(unittest.TestCase):
    def setUp(self):
        self.transformer = TfidfTransformer()
        self.documents = ['A Scandal in Bohemia', 'The Red-headed League', 'A Case of Identity', 'The Boscombe Valley Mystery', 'The Five Orange Pips', 'The Man with the Twisted Lip', 'The Adventure of the Blue Carbuncle', 'The Adventure of the Speckled Band', 'The Adventure of the Noble Bachelor']

    def test_fit(self):
        self.transformer.fit(self.documents)
        self.assertIsNotNone(self.transformer.tfidf)
    
    def test_fit_invalid_input(self):
        with self.assertRaises(ValueError):
            self.transformer.fit(None)
    
    def test_transform(self):
        self.transformer.fit(self.documents)
        transform = self.transformer.transform(self.documents)
        self.assertIsInstance(transform)
    
    def test_transform_invalid_input(self):
        with self.assertRaises(ValueError):
            self.transformer.transform(None)
        
    def test_fit_transform(self):
        fit_transform = self.transformer.fit_transform(self.documents)
        self.assertIsInstance(fit_transform)

    def test_fit_transform_invalid_input(self):
        with self.assertRaises(ValueError):
            self.transformer.fit_transform(None)
        
    def test_get_feature_names(self):
        self.transformer.fit(self.documents)
        feature_names = self.transformer.get_feature_names()
        self.assertIsInstance(feature_names,list)

if __name__ == '__main__':
    unittest.main()


from sklearn.feature_extraction.text import TfidfVectorizer

class TfidfTransformer:
    """
    A class for allows to use fit,transform and fit_transform methods of TfidfVectorizer

    Attributes
    ----------
    documents: str
        string documents to fit the transformer

    Methods
    -------
    fit(documents):
        Allows the use of the fit method in TfidfVectorizer.
    transform(documents):
        Allows the use of the transform method in TfidfVectorizer.
    fit_transform(documents):
        Allows the use of the fit_transform method in TfidfVectorizer.
    get_feature_names:
        Allows the use of the get_feature_names method in TfidfVectorizer.
    """
    def __init__(self):
        self.tfidf = TfidfVectorizer()

    def fit(self, documents):
        """
        Fit the transformer to the given documents.
        
        Parameters
        ----------
        documents: str
            string documents to fit the transformer
        
        Returns
        -------
        None
        """
        self.tfidf.fit(documents)

    def transform(self, documents):
        """
        Transform a documents

        Parameters
        ----------
        documents: str
            string documents to transform
        
        Returns
        -------
        transformed documents in sparse matrix format
        """
        return self.tfidf.transform(documents)
    
    def fit_transform(self, documents):
        """
        Fit and transform the transformer to the given string documents
        
        Parameters
        ----------
        documents: str
            string documents to fit and transform
        
        Returns
        -------
        transformed documents in parsing matrix format
        """
        return self.tfidf.fit_transform(documents)
    
    def get_feature_names(self):
        """
        Returns the feature names
        """
        return self.tfidf.get_feature_names()


import setuptools

setuptools.setup(
    name="tfidf_transformation_berk",
    version="0.1.0",
    author="Berk Ozturk",
    description="a package for tf-idf transformation with using sklearn's tfidf function ",
    packages=["tfidf_transformation_berk"]
)